@@ -2,7 +2,7 @@
 
 package Git::Hooks::GerritChangeId;
 # ABSTRACT: Git::Hooks plugin to insert a Change-Id in a commit message.
-$Git::Hooks::GerritChangeId::VERSION = '1.6.2';
+$Git::Hooks::GerritChangeId::VERSION = '1.6.3';
 use 5.010;
 use utf8;
 use strict;
@@ -53,7 +53,9 @@ sub insert_change_id {
     my $cmsg = Git::More::Message->new($msg);
 
     # Don't mess with the message if it's empty.
-    if ($cmsg->title !~ /\S/ && $cmsg->body !~ /\S/) {
+    if (   (! defined $cmsg->title || $cmsg->title !~ /\S/)
+        && (! defined $cmsg->body  || $cmsg->body  !~ /\S/)
+       ) {
         # (Signed-off-by footers don't count.)
         my @footer = $cmsg->get_footer_keys;
         return if @footer == 0 || @footer == 1 && $footer[0] eq 'signed-off-by';
@@ -99,7 +101,7 @@ Git::Hooks::GerritChangeId - Git::Hooks plugin to insert a Change-Id in a commit
 
 =head1 VERSION
 
-version 1.6.2
+version 1.6.3
 
 =head1 DESCRIPTION
 
